@@ -5,14 +5,16 @@ import contextlib
 import copy
 import functools
 import os
+from contextlib import ExitStack
+from json import JSONDecodeError
 
 import attr
-import packaging.markers
-import packaging.version
 import pip_shims.shims
 import requests
+from packaging.markers import Marker
 from packaging.utils import canonicalize_name
-from vistir.compat import JSONDecodeError, fs_str
+from packaging.version import parse
+from vistir.compat import fs_str
 from vistir.contextmanagers import cd, temp_environ
 from vistir.path import create_tracked_tempdir
 
@@ -32,31 +34,27 @@ from .utils import (
     version_from_ireq,
 )
 
-try:
-    from contextlib import ExitStack
-except ImportError:
-    from contextlib2 import ExitStack
-
 if MYPY_RUNNING:
     from typing import (
         Any,
         Dict,
-        List,
         Generator,
+        List,
         Optional,
-        Union,
+        Set,
+        Text,
         Tuple,
         TypeVar,
-        Text,
-        Set,
-    )
-    from pip_shims.shims import (
-        InstallRequirement,
-        InstallationCandidate,
-        PackageFinder,
-        Command,
+        Union,
     )
+
     from packaging.requirements import Requirement as PackagingRequirement
+    from pip_shims.shims import (
+        Command,
+        InstallationCandidate,
+        InstallRequirement,
+        PackageFinder,
+    )
 
     TRequirement = TypeVar("TRequirement")
     RequirementType = TypeVar(
@@ -71,9 +69,14 @@ PKGS_DOWNLOAD_DIR = fs_str(os.path.join(CACHE_DIR, "pkgs"))
 WHEEL_DOWNLOAD_DIR = fs_str(os.path.join(CACHE_DIR, "wheels"))
 
 DEPENDENCY_CACHE = DependencyCache()
-WHEEL_CACHE = pip_shims.shims.WheelCache(
-    CACHE_DIR, pip_shims.shims.FormatControl(set(), set())
-)
+
+
+@contextlib.contextmanager
+def _get_wheel_cache():
+    with pip_shims.shims.global_tempdir_manager():
+        yield pip_shims.shims.WheelCache(
+            CACHE_DIR, pip_shims.shims.FormatControl(set(), set())
+        )
 
 
 def _get_filtered_versions(ireq, versions, prereleases):
@@ -82,8 +85,8 @@ def _get_filtered_versions(ireq, versions, prereleases):
 
 def find_all_matches(finder, ireq, pre=False):
     # type: (PackageFinder, InstallRequirement, bool) -> List[InstallationCandidate]
-    """Find all matching dependencies using the supplied finder and the
-    given ireq.
+    """Find all matching dependencies using the supplied finder and the given
+    ireq.
 
     :param finder: A package finder for discovering matching candidates.
     :type finder: :class:`~pip._internal.index.PackageFinder`
@@ -124,7 +127,8 @@ class AbstractDependency(object):
 
     @property
     def version_set(self):
-        """Return the set of versions for the candidates in this abstract dependency.
+        """Return the set of versions for the candidates in this abstract
+        dependency.
 
         :return: A set of matching versions
         :rtype: set(str)
@@ -132,11 +136,11 @@ class AbstractDependency(object):
 
         if len(self.candidates) == 1:
             return set()
-        return set(packaging.version.parse(version_from_ireq(c)) for c in self.candidates)
+        return set(parse(version_from_ireq(c)) for c in self.candidates)
 
     def compatible_versions(self, other):
-        """Find compatible version numbers between this abstract
-        dependency and another one.
+        """Find compatible version numbers between this abstract dependency and
+        another one.
 
         :param other: An abstract dependency to compare with.
         :type other: :class:`~requirementslib.models.dependency.AbstractDependency`
@@ -173,9 +177,7 @@ class AbstractDependency(object):
             markers.add(other.markers)
         new_markers = None
         if markers:
-            new_markers = packaging.markers.Marker(
-                " or ".join(str(m) for m in sorted(markers))
-            )
+            new_markers = Marker(" or ".join(str(m) for m in sorted(markers)))
         new_ireq = copy.deepcopy(self.requirement.ireq)
         new_ireq.req.specifier = new_specifiers
         new_ireq.req.marker = new_markers
@@ -186,7 +188,7 @@ class AbstractDependency(object):
         candidates = [
             c
             for c in self.candidates
-            if packaging.version.parse(version_from_ireq(c)) in compatible_versions
+            if parse(version_from_ireq(c)) in compatible_versions
         ]
         dep_dict = {}
         candidate_strings = [format_requirement(c) for c in candidates]
@@ -224,8 +226,9 @@ class AbstractDependency(object):
 
     @classmethod
     def from_requirement(cls, requirement, parent=None):
-        """Creates a new :class:`~requirementslib.models.dependency.AbstractDependency`
-        from a :class:`~requirementslib.models.requirements.Requirement` object.
+        """Creates a new
+        :class:`~requirementslib.models.dependency.AbstractDependency` from a
+        :class:`~requirementslib.models.requirements.Requirement` object.
 
         This class is used to find all candidates matching a given set of specifiers
         and a given requirement.
@@ -255,7 +258,7 @@ class AbstractDependency(object):
                 candidates.append(req)
                 candidates = sorted(
                     set(candidates),
-                    key=lambda k: packaging.version.parse(version_from_ireq(k)),
+                    key=lambda k: parse(version_from_ireq(k)),
                 )
         else:
             candidates = [requirement.ireq]
@@ -351,7 +354,9 @@ def get_dependencies(ireq, sources=None, parent=None):
 
 
 def get_dependencies_from_wheel_cache(ireq):
-    """Retrieves dependencies for the given install requirement from the wheel cache.
+    # type: (pip_shims.shims.InstallRequirement) -> Optional[Set[pip_shims.shims.InstallRequirement]]
+    """Retrieves dependencies for the given install requirement from the wheel
+    cache.
 
     :param ireq: A single InstallRequirement
     :type ireq: :class:`~pip._internal.req.req_install.InstallRequirement`
@@ -361,13 +366,14 @@ def get_dependencies_from_wheel_cache(ireq):
 
     if ireq.editable or not is_pinned_requirement(ireq):
         return
-    matches = WHEEL_CACHE.get(ireq.link, name_from_req(ireq.req))
-    if matches:
-        matches = set(matches)
-        if not DEPENDENCY_CACHE.get(ireq):
-            DEPENDENCY_CACHE[ireq] = [format_requirement(m) for m in matches]
-        return matches
-    return
+    with _get_wheel_cache() as wheel_cache:
+        matches = wheel_cache.get(ireq.link, name_from_req(ireq.req))
+        if matches:
+            matches = set(matches)
+            if not DEPENDENCY_CACHE.get(ireq):
+                DEPENDENCY_CACHE[ireq] = [format_requirement(m) for m in matches]
+            return matches
+        return None
 
 
 def _marker_contains_extra(ireq):
@@ -376,7 +382,8 @@ def _marker_contains_extra(ireq):
 
 
 def get_dependencies_from_json(ireq):
-    """Retrieves dependencies for the given install requirement from the json api.
+    """Retrieves dependencies for the given install requirement from the json
+    api.
 
     :param ireq: A single InstallRequirement
     :type ireq: :class:`~pip._internal.req.req_install.InstallRequirement`
@@ -425,7 +432,8 @@ def get_dependencies_from_json(ireq):
 
 
 def get_dependencies_from_cache(ireq):
-    """Retrieves dependencies for the given install requirement from the dependency cache.
+    """Retrieves dependencies for the given install requirement from the
+    dependency cache.
 
     :param ireq: A single InstallRequirement
     :type ireq: :class:`~pip._internal.req.req_install.InstallRequirement`
@@ -466,7 +474,8 @@ def is_python(section):
 
 
 def get_dependencies_from_index(dep, sources=None, pip_options=None, wheel_cache=None):
-    """Retrieves dependencies for the given install requirement from the pip resolver.
+    """Retrieves dependencies for the given install requirement from the pip
+    resolver.
 
     :param dep: A single InstallRequirement
     :type dep: :class:`~pip._internal.req.req_install.InstallRequirement`
@@ -477,12 +486,12 @@ def get_dependencies_from_index(dep, sources=None, pip_options=None, wheel_cache
     """
 
     session, finder = get_finder(sources=sources, pip_options=pip_options)
-    if not wheel_cache:
-        wheel_cache = WHEEL_CACHE
     dep.is_direct = True
     requirements = None
     setup_requires = {}
-    with temp_environ():
+    with temp_environ(), ExitStack() as stack:
+        if not wheel_cache:
+            wheel_cache = stack.enter_context(_get_wheel_cache())
         os.environ["PIP_EXISTS_ACTION"] = "i"
         if dep.editable and not dep.prepared and not dep.req:
             setup_info = SetupInfo.from_ireq(dep)
@@ -498,8 +507,8 @@ def get_dependencies_from_index(dep, sources=None, pip_options=None, wheel_cache
     return requirements
 
 
-def get_pip_options(args=[], sources=None, pip_command=None):
-    """Build a pip command from a list of sources
+def get_pip_options(args=None, sources=None, pip_command=None):
+    """Build a pip command from a list of sources.
 
     :param args: positional arguments passed through to the pip parser
     :param sources: A list of pipfile-formatted sources, defaults to None
@@ -515,7 +524,7 @@ def get_pip_options(args=[], sources=None, pip_command=None):
     if not sources:
         sources = [{"url": "https://pypi.org/simple", "name": "pypi", "verify_ssl": True}]
     _ensure_dir(CACHE_DIR)
-    pip_args = args
+    pip_args = args or []
     pip_args = prepare_pip_source_args(sources, pip_args)
     pip_options, _ = pip_command.parser.parse_args(pip_args)
     pip_options.cache_dir = CACHE_DIR
@@ -524,7 +533,7 @@ def get_pip_options(args=[], sources=None, pip_command=None):
 
 def get_finder(sources=None, pip_command=None, pip_options=None):
     # type: (List[Dict[S, Union[S, bool]]], Optional[Command], Any) -> PackageFinder
-    """Get a package finder for looking up candidates to install
+    """Get a package finder for looking up candidates to install.
 
     :param sources: A list of pipfile-formatted sources, defaults to None
     :param sources: list[dict], optional
@@ -559,7 +568,8 @@ def start_resolver(finder=None, session=None, wheel_cache=None):
     :param :class:`~requests.Session` session: A session instance
     :param :class:`~pip._internal.cache.WheelCache` wheel_cache: A pip WheelCache instance
     :return: A 3-tuple of finder, preparer, resolver
-    :rtype: (:class:`~pip._internal.operations.prepare.RequirementPreparer`, :class:`~pip._internal.resolve.Resolver`)
+    :rtype: (:class:`~pip._internal.operations.prepare.RequirementPreparer`,
+             :class:`~pip._internal.resolve.Resolver`)
     """
 
     pip_command = get_pip_command()
@@ -570,10 +580,6 @@ def start_resolver(finder=None, session=None, wheel_cache=None):
     if not session:
         session = pip_command._build_session(pip_options)
 
-    if not wheel_cache:
-        wheel_cache = WHEEL_CACHE
-    _ensure_dir(fs_str(os.path.join(wheel_cache.cache_dir, "wheels")))
-
     download_dir = PKGS_DOWNLOAD_DIR
     _ensure_dir(download_dir)
 
@@ -582,6 +588,9 @@ def start_resolver(finder=None, session=None, wheel_cache=None):
     try:
         with ExitStack() as ctx:
             ctx.enter_context(pip_shims.shims.global_tempdir_manager())
+            if not wheel_cache:
+                wheel_cache = ctx.enter_context(_get_wheel_cache())
+            _ensure_dir(fs_str(os.path.join(wheel_cache.cache_dir, "wheels")))
             preparer = ctx.enter_context(
                 pip_shims.shims.make_preparer(
                     options=pip_options,
