@@ -17,13 +17,12 @@ from urllib.parse import parse_qs, urlparse, urlunparse
 from weakref import finalize
 
 import attr
-import packaging.specifiers
-import packaging.utils
-import packaging.version
 import pep517.envbuild
 import pep517.wrappers
 from distlib.wheel import Wheel
 from packaging.markers import Marker
+from packaging.specifiers import SpecifierSet
+from packaging.version import parse
 from pip_shims.utils import call_function_with_correct_args
 from platformdirs import user_cache_dir
 from vistir.contextmanagers import cd, temp_path
@@ -493,15 +492,17 @@ class SetupReader:
             if not isinstance(elem, (ast.Assign, ast.AnnAssign)):
                 continue
 
-            if getattr(elem, "target", None) and elem.target.id == name:
-                return elem.value
-
-            for target in elem.targets:
-                if not isinstance(target, ast.Name):
+            if isinstance(elem, ast.AnnAssign):
+                if not isinstance(elem.target, ast.Name):
                     continue
-
-                if target.id == name:
+                if elem.value and elem.target.id == name:
                     return elem.value
+            else:
+                for target in elem.targets:
+                    if not isinstance(target, ast.Name):
+                        continue
+                    if target.id == name:
+                        return elem.value
         return None
 
     @staticmethod
@@ -1015,9 +1016,7 @@ class SetupInfo(object):
     build_requires = attr.ib(default=None, eq=True)  # type: Optional[Tuple]
     build_backend = attr.ib(eq=True)  # type: STRING_TYPE
     setup_requires = attr.ib(default=None, eq=True)  # type: Optional[Tuple]
-    python_requires = attr.ib(
-        default=None, eq=True
-    )  # type: Optional[packaging.specifiers.SpecifierSet]
+    python_requires = attr.ib(default=None, eq=True)  # type: Optional[SpecifierSet]
     _extras_requirements = attr.ib(default=None, eq=True)  # type: Optional[Tuple]
     setup_cfg = attr.ib(type=Path, default=None, eq=True, hash=False)
     setup_py = attr.ib(type=Path, default=None, eq=True, hash=False)
@@ -1096,7 +1095,7 @@ class SetupInfo(object):
         version = metadata.get("version", None)
         if version:
             try:
-                packaging.version.parse(version)
+                parse(version)
             except TypeError:
                 version = self.version if self.version else None
             else:
@@ -1565,13 +1564,30 @@ build-backend = "{1}"
             }
             call_function_with_correct_args(build_location_func, **build_kwargs)
             ireq.ensure_has_source_dir(kwargs["src_dir"])
-            pip_shims.shims.shim_unpack(
-                download_dir=download_dir,
-                ireq=ireq,
-                only_download=only_download,
-                session=session,
-                hashes=ireq.hashes(False),
-            )
+            try:  # Support for pip >= 21.1
+                from pip._internal.network.download import Downloader
+
+                from requirementslib.models.old_pip_utils import old_unpack_url
+
+                location = None
+                if getattr(ireq, "source_dir", None):
+                    location = ireq.source_dir
+                old_unpack_url(
+                    link=ireq.link,
+                    location=location,
+                    download=Downloader(session, "off"),
+                    verbosity=1,
+                    download_dir=download_dir,
+                    hashes=ireq.hashes(True),
+                )
+            except ImportError:
+                pip_shims.shims.shim_unpack(
+                    download_dir=download_dir,
+                    ireq=ireq,
+                    only_download=only_download,
+                    session=session,
+                    hashes=ireq.hashes(False),
+                )
         created = cls.create(
             ireq.source_dir, subdirectory=subdir, ireq=ireq, kwargs=kwargs, stack=stack
         )
